==> haskell-skylighting-0.1.1.5-23-i686.pkg.tar.xz: usr/share/haskell/register/haskell-skylighting.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: skylighting
version: 0.1.1.5
id: skylighting-0.1.1.5-5yoD5z8tp63L7KqOjjdunL
key: skylighting-0.1.1.5-5yoD5z8tp63L7KqOjjdunL
license: GPL-2
copyright: (C) 2016 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: https://github.com/jgm/skylighting
synopsis: syntax highlighting library
description:
    Skylighting is a syntax highlighting library with
    support for over one hundred languages.  It derives
    its tokenizers from XML syntax definitions used
    by KDE'\''s KSyntaxHighlighting framework, so any
    syntax supported by that framework can be added.
    An optional command-line program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
category: Text
author: John MacFarlane
exposed: True
exposed-modules:
    Skylighting Skylighting.Types Skylighting.Regex Skylighting.Parser
    Skylighting.Styles Skylighting.Tokenizer Skylighting.Format.HTML
    Skylighting.Format.LaTeX Skylighting.Syntax
hidden-modules: Skylighting.Syntax.Abc
                Skylighting.Syntax.Actionscript Skylighting.Syntax.Ada
                Skylighting.Syntax.Agda Skylighting.Syntax.Alert
                Skylighting.Syntax.AlertIndent Skylighting.Syntax.Apache
                Skylighting.Syntax.Asn1 Skylighting.Syntax.Asp
                Skylighting.Syntax.Ats Skylighting.Syntax.Awk
                Skylighting.Syntax.Bash Skylighting.Syntax.Bibtex
                Skylighting.Syntax.Boo Skylighting.Syntax.C
                Skylighting.Syntax.Changelog Skylighting.Syntax.Clojure
                Skylighting.Syntax.Cmake Skylighting.Syntax.Coffee
                Skylighting.Syntax.Coldfusion Skylighting.Syntax.Commonlisp
                Skylighting.Syntax.Cpp Skylighting.Syntax.Cs Skylighting.Syntax.Css
                Skylighting.Syntax.Curry Skylighting.Syntax.D
                Skylighting.Syntax.Diff Skylighting.Syntax.Djangotemplate
                Skylighting.Syntax.Dockerfile Skylighting.Syntax.Dot
                Skylighting.Syntax.Doxygen Skylighting.Syntax.Doxygenlua
                Skylighting.Syntax.Dtd Skylighting.Syntax.Eiffel
                Skylighting.Syntax.Elixir Skylighting.Syntax.Email
                Skylighting.Syntax.Erlang Skylighting.Syntax.Fasm
                Skylighting.Syntax.Fortran Skylighting.Syntax.Fsharp
                Skylighting.Syntax.Gcc Skylighting.Syntax.Glsl
                Skylighting.Syntax.Gnuassembler Skylighting.Syntax.Go
                Skylighting.Syntax.Hamlet Skylighting.Syntax.Haskell
                Skylighting.Syntax.Haxe Skylighting.Syntax.Html
                Skylighting.Syntax.Idris Skylighting.Syntax.Ini
                Skylighting.Syntax.Isocpp Skylighting.Syntax.Java
                Skylighting.Syntax.Javadoc Skylighting.Syntax.Javascript
                Skylighting.Syntax.Json Skylighting.Syntax.Jsp
                Skylighting.Syntax.Julia Skylighting.Syntax.Kotlin
                Skylighting.Syntax.Latex Skylighting.Syntax.Lex
                Skylighting.Syntax.Lilypond Skylighting.Syntax.LiterateCurry
                Skylighting.Syntax.LiterateHaskell Skylighting.Syntax.Llvm
                Skylighting.Syntax.Lua Skylighting.Syntax.M4
                Skylighting.Syntax.Makefile Skylighting.Syntax.Mandoc
                Skylighting.Syntax.Markdown Skylighting.Syntax.Mathematica
                Skylighting.Syntax.Matlab Skylighting.Syntax.Maxima
                Skylighting.Syntax.Mediawiki Skylighting.Syntax.Metafont
                Skylighting.Syntax.Mips Skylighting.Syntax.Modelines
                Skylighting.Syntax.Modula2 Skylighting.Syntax.Modula3
                Skylighting.Syntax.Monobasic Skylighting.Syntax.Nasm
                Skylighting.Syntax.Noweb Skylighting.Syntax.Objectivec
                Skylighting.Syntax.Objectivecpp Skylighting.Syntax.Ocaml
                Skylighting.Syntax.Octave Skylighting.Syntax.Opencl
                Skylighting.Syntax.Pascal Skylighting.Syntax.Perl
                Skylighting.Syntax.Php Skylighting.Syntax.Pike
                Skylighting.Syntax.Postscript Skylighting.Syntax.Prolog
                Skylighting.Syntax.Pure Skylighting.Syntax.Purebasic
                Skylighting.Syntax.Python Skylighting.Syntax.R
                Skylighting.Syntax.Relaxng Skylighting.Syntax.Relaxngcompact
                Skylighting.Syntax.Rest Skylighting.Syntax.Rhtml
                Skylighting.Syntax.Roff Skylighting.Syntax.Ruby
                Skylighting.Syntax.Rust Skylighting.Syntax.Scala
                Skylighting.Syntax.Scheme Skylighting.Syntax.Sci
                Skylighting.Syntax.Sed Skylighting.Syntax.Sgml
                Skylighting.Syntax.SqlMysql Skylighting.Syntax.SqlPostgresql
                Skylighting.Syntax.Sql Skylighting.Syntax.Tcl
                Skylighting.Syntax.Tcsh Skylighting.Syntax.Texinfo
                Skylighting.Syntax.Verilog Skylighting.Syntax.Vhdl
                Skylighting.Syntax.Xml Skylighting.Syntax.Xorg
                Skylighting.Syntax.Xslt Skylighting.Syntax.Xul
                Skylighting.Syntax.Yacc Skylighting.Syntax.Yaml
                Skylighting.Syntax.Zsh
abi: 5eafffe8e86e108e8a551195d564eee4
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/skylighting-0.1.1.5
library-dirs: /usr/lib/ghc-8.0.2/site-local/skylighting-0.1.1.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/skylighting-0.1.1.5
hs-libraries: HSskylighting-0.1.1.5-5yoD5z8tp63L7KqOjjdunL
depends:
    aeson-1.1.2.0-H9d5B7Pgw9tIbOpl8Ot3sY base-4.9.1.0
    blaze-html-0.8.1.3-EHw0sCLFL6JKZx2lFkE5O8 bytestring-0.10.8.1
    case-insensitive-1.2.0.10-3Sa52nt2lVR6gZGQE5fZZw containers-0.5.7.1
    directory-1.3.0.0 filepath-1.4.1.1
    hxt-9.3.1.16-YawaVI4czs2GYj8uhLpnV mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    regex-pcre-0.94.4-FoWT2VQCFeqKub0RjpiMo1
    safe-0.3.15-2Yd45VWFfdcKqKyispOifY
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    utf8-string-1.0.1.1-1DpjxLeTvGg7ttZZojxJR5
haddock-interfaces: /usr/share/doc/haskell-skylighting/html/skylighting.haddock
haddock-html: /usr/share/doc/haskell-skylighting/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-0.1.1.5-25-i686.pkg.tar.xz: usr/share/haskell/register/haskell-skylighting.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: skylighting
version: 0.1.1.5
id: skylighting-0.1.1.5-AGyqFeTIf40I0Seb0kbW0Q
key: skylighting-0.1.1.5-AGyqFeTIf40I0Seb0kbW0Q
license: GPL-2
copyright: (C) 2016 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: https://github.com/jgm/skylighting
synopsis: syntax highlighting library
description:
    Skylighting is a syntax highlighting library with
    support for over one hundred languages.  It derives
    its tokenizers from XML syntax definitions used
    by KDE'\''s KSyntaxHighlighting framework, so any
    syntax supported by that framework can be added.
    An optional command-line program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
category: Text
author: John MacFarlane
exposed: True
exposed-modules:
    Skylighting Skylighting.Types Skylighting.Regex Skylighting.Parser
    Skylighting.Styles Skylighting.Tokenizer Skylighting.Format.HTML
    Skylighting.Format.LaTeX Skylighting.Syntax
hidden-modules: Skylighting.Syntax.Abc
                Skylighting.Syntax.Actionscript Skylighting.Syntax.Ada
                Skylighting.Syntax.Agda Skylighting.Syntax.Alert
                Skylighting.Syntax.AlertIndent Skylighting.Syntax.Apache
                Skylighting.Syntax.Asn1 Skylighting.Syntax.Asp
                Skylighting.Syntax.Ats Skylighting.Syntax.Awk
                Skylighting.Syntax.Bash Skylighting.Syntax.Bibtex
                Skylighting.Syntax.Boo Skylighting.Syntax.C
                Skylighting.Syntax.Changelog Skylighting.Syntax.Clojure
                Skylighting.Syntax.Cmake Skylighting.Syntax.Coffee
                Skylighting.Syntax.Coldfusion Skylighting.Syntax.Commonlisp
                Skylighting.Syntax.Cpp Skylighting.Syntax.Cs Skylighting.Syntax.Css
                Skylighting.Syntax.Curry Skylighting.Syntax.D
                Skylighting.Syntax.Diff Skylighting.Syntax.Djangotemplate
                Skylighting.Syntax.Dockerfile Skylighting.Syntax.Dot
                Skylighting.Syntax.Doxygen Skylighting.Syntax.Doxygenlua
                Skylighting.Syntax.Dtd Skylighting.Syntax.Eiffel
                Skylighting.Syntax.Elixir Skylighting.Syntax.Email
                Skylighting.Syntax.Erlang Skylighting.Syntax.Fasm
                Skylighting.Syntax.Fortran Skylighting.Syntax.Fsharp
                Skylighting.Syntax.Gcc Skylighting.Syntax.Glsl
                Skylighting.Syntax.Gnuassembler Skylighting.Syntax.Go
                Skylighting.Syntax.Hamlet Skylighting.Syntax.Haskell
                Skylighting.Syntax.Haxe Skylighting.Syntax.Html
                Skylighting.Syntax.Idris Skylighting.Syntax.Ini
                Skylighting.Syntax.Isocpp Skylighting.Syntax.Java
                Skylighting.Syntax.Javadoc Skylighting.Syntax.Javascript
                Skylighting.Syntax.Json Skylighting.Syntax.Jsp
                Skylighting.Syntax.Julia Skylighting.Syntax.Kotlin
                Skylighting.Syntax.Latex Skylighting.Syntax.Lex
                Skylighting.Syntax.Lilypond Skylighting.Syntax.LiterateCurry
                Skylighting.Syntax.LiterateHaskell Skylighting.Syntax.Llvm
                Skylighting.Syntax.Lua Skylighting.Syntax.M4
                Skylighting.Syntax.Makefile Skylighting.Syntax.Mandoc
                Skylighting.Syntax.Markdown Skylighting.Syntax.Mathematica
                Skylighting.Syntax.Matlab Skylighting.Syntax.Maxima
                Skylighting.Syntax.Mediawiki Skylighting.Syntax.Metafont
                Skylighting.Syntax.Mips Skylighting.Syntax.Modelines
                Skylighting.Syntax.Modula2 Skylighting.Syntax.Modula3
                Skylighting.Syntax.Monobasic Skylighting.Syntax.Nasm
                Skylighting.Syntax.Noweb Skylighting.Syntax.Objectivec
                Skylighting.Syntax.Objectivecpp Skylighting.Syntax.Ocaml
                Skylighting.Syntax.Octave Skylighting.Syntax.Opencl
                Skylighting.Syntax.Pascal Skylighting.Syntax.Perl
                Skylighting.Syntax.Php Skylighting.Syntax.Pike
                Skylighting.Syntax.Postscript Skylighting.Syntax.Prolog
                Skylighting.Syntax.Pure Skylighting.Syntax.Purebasic
                Skylighting.Syntax.Python Skylighting.Syntax.R
                Skylighting.Syntax.Relaxng Skylighting.Syntax.Relaxngcompact
                Skylighting.Syntax.Rest Skylighting.Syntax.Rhtml
                Skylighting.Syntax.Roff Skylighting.Syntax.Ruby
                Skylighting.Syntax.Rust Skylighting.Syntax.Scala
                Skylighting.Syntax.Scheme Skylighting.Syntax.Sci
                Skylighting.Syntax.Sed Skylighting.Syntax.Sgml
                Skylighting.Syntax.SqlMysql Skylighting.Syntax.SqlPostgresql
                Skylighting.Syntax.Sql Skylighting.Syntax.Tcl
                Skylighting.Syntax.Tcsh Skylighting.Syntax.Texinfo
                Skylighting.Syntax.Verilog Skylighting.Syntax.Vhdl
                Skylighting.Syntax.Xml Skylighting.Syntax.Xorg
                Skylighting.Syntax.Xslt Skylighting.Syntax.Xul
                Skylighting.Syntax.Yacc Skylighting.Syntax.Yaml
                Skylighting.Syntax.Zsh
abi: 863b45e99ed9733cde951dc9c2d13c5b
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/skylighting-0.1.1.5
library-dirs: /usr/lib/ghc-8.0.2/site-local/skylighting-0.1.1.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/skylighting-0.1.1.5
hs-libraries: HSskylighting-0.1.1.5-AGyqFeTIf40I0Seb0kbW0Q
depends:
    aeson-1.1.2.0-2Tms2Hc2yE36x3yS5aZqW9 base-4.9.1.0
    blaze-html-0.8.1.3-EHw0sCLFL6JKZx2lFkE5O8 bytestring-0.10.8.1
    case-insensitive-1.2.0.10-3Sa52nt2lVR6gZGQE5fZZw containers-0.5.7.1
    directory-1.3.0.0 filepath-1.4.1.1
    hxt-9.3.1.16-YawaVI4czs2GYj8uhLpnV mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    regex-pcre-0.94.4-FoWT2VQCFeqKub0RjpiMo1
    safe-0.3.15-2Yd45VWFfdcKqKyispOifY
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    utf8-string-1.0.1.1-1DpjxLeTvGg7ttZZojxJR5
haddock-interfaces: /usr/share/doc/haskell-skylighting/html/skylighting.haddock
haddock-html: /usr/share/doc/haskell-skylighting/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
